@@ -115,7 +115,7 @@ def create_video(list_comp_data, path_video, job_id, mf_server):
     indexVidBG=0
     #check if videos are compilation
     for comp in arr_comps:
-        if indexVidBG < 5 and  (comp.type == "video" or comp.type == "image"):
+        if indexVidBG < 5 and  (comp.type == "image"):
             firstImageOrVideoBG.append(comp.make())
             indexVidBG+=1
 
@@ -537,13 +537,16 @@ class VideoComp(Component):
             self.video_path = download_file(self.video_url, ext=self.ext)
         has_mask = False
         if self.ext == "gif":
-            has_mask= True
-            self.video_path = FFmpeg.convert_gif(self.video_path)
+            if self.opacity < 1.0:
+                self.video_path = FFmpeg.convert_gif_moviepy(self.video_path)
+            else:
+                has_mask = True
+                self.video_path = FFmpeg.convert_gif(self.video_path)
         if self.ext == "mov":
             has_mask = True
         rs = VideoFileClip(self.video_path, audio=not self.isMute, has_mask=has_mask)
         self.real_duration = rs.duration
-        if (self.index == 0 or self.isLoop) and rs.duration < 1200: #max 20 mins loop
+        if (self.index == 0 or self.isLoop) and rs.duration < 600: #max 20 mins loop
             rs.close()
             self.video_path = create_loop(self.video_path, 600)
             rs = VideoFileClip(self.video_path, audio=not self.isMute, has_mask=has_mask)
