@@ -5,6 +5,7 @@ import uuid,json, shutil,os
 from moviepy.editor import *
 import subprocess
 import urllib
+import time
 def download_audio(url, ext='mp3', retries= 3):
     try:
         file_name = str(uuid.uuid4()) + "." + ext
@@ -79,6 +80,17 @@ def fade_audio(audio_path, fade_time=3, dur=30):
     process.wait()
     os.remove(audio_path)
     return tmp_clip_path
+def check_song(file_path):
+    try:
+        audio_test = AudioFileClip(file_path)
+        audioduration = audio_test.duration
+        audio_test.close()
+        if audioduration < 1:
+            return False
+    except:
+        return False
+        pass
+    return True
 def create_compilation_songs(data, job_id, mf_server):
     #[{"type":3,"url":"","repeat":1}]
     #3: youtube_video
@@ -103,9 +115,14 @@ def create_compilation_songs(data, job_id, mf_server):
                     if "gdrive" in tmp:
                         ext="mp3"
                     song['local'] = download_file(tmp,ext=ext)
+                    # cnt_retries = 0
+                    # while (not check_song(song['local'])) and cnt_retries<3:
+                    #     time.sleep(1)
+                    #     song['local'] = download_file(tmp, ext=ext)
+                    #     cnt_retries += 1
                 if arr_tmp[0] == "deezer":#deezer
                     song_info=requests.get("http://source.automusic.win/deezer/track/get/"+arr_tmp[2], timeout=180).json()
-                    song['local']=download_file(song_info['url_128'])
+                    song['local'] = download_file(song_info['url_128'])
                 if arr_tmp[0] == "spotify":  # spotify
                     arr_song_info = requests.get("http://source.automusic.win/spotify/track/get/" + arr_tmp[2], timeout= 180).json()
                     if len(arr_song_info)>0:
@@ -124,16 +141,8 @@ def create_compilation_songs(data, job_id, mf_server):
                             pass
 
                 #after download song, re-check song
-                try:
-                    audio_test = AudioFileClip(song['local'])
-                    audioduration = audio_test.duration
-                    audio_test.close()
-                    if audioduration < 1:
-                        continue
-                except:
+                if not check_song(song['local']):
                     continue
-                    pass
-
                 song['local']=normal_audio(song['local'])
                 if song['repeat'] > 1:
                     song['local']= create_loop_audio_times(song['local'], song['repeat'])
